Module spec

Module spec 

The neutral run identity handed to a harness at start. The neutral run identity handed to a harness at crate::AgentHarness::start.

Structs

AgentRunSpec
The neutral identity + input for one agent run (one activity attempt).