The neutral run identity handed to a harness at start.
The neutral run identity handed to a harness at crate::AgentHarness::start.
Structs
- Agent
RunSpec - The neutral identity + input for one agent run (one activity attempt).
The neutral run identity handed to a harness at start.
The neutral run identity handed to a harness at crate::AgentHarness::start.